vortex_layout::layouts::chunked::stats_table

Struct StatsTable

pub struct StatsTable { /* private fields */ }
A table of statistics for a column. Each row of the stats table corresponds to a chunk of the column.

Note that it’s possible for the stats table to have no statistics.

Implementations

Source

impl StatsTable

pub fn try_new( column_dtype: DType, array: ArrayData, stats: Arc<[Stat]>, ) -> VortexResult<Self>

pub fn dtype_for_stats_table( column_dtype: &DType, present_stats: &[Stat], ) -> DType

Returns the DType of the statistics table given a set of statistics and column DType.

pub fn column_dtype(&self) -> &DType

The DType of the column for which these stats are computed.

pub fn array(&self) -> &ArrayData

The struct array backing the stats table

pub fn present_stats(&self) -> &[Stat]

The statistics that are included in the table.

pub fn to_stats_set(&self, stats: &[Stat]) -> VortexResult<StatsSet>

Return an aggregated stats set for the table.

pub fn get_stat(&self, stat: Stat) -> VortexResult<Option<ArrayData>>

Return the array for a given stat.