Struct DictStrategy

pub struct DictStrategy { /* private fields */ }
A layout strategy that encodes chunk into values and codes, if found appropriate by the btrblocks compressor. Current implementation only checks the first chunk to decide whether to apply dict layout and encodes chunks into dictionaries. When the dict constraints are hit, a new dictionary is created.

Implementations

Source

impl DictStrategy

pub fn new( codes: ArcRef<dyn LayoutStrategy>, values: ArcRef<dyn LayoutStrategy>, fallback: ArcRef<dyn LayoutStrategy>, options: DictLayoutOptions, executor: Arc<dyn TaskExecutor>, ) -> Self