pub struct FlatLayout;Trait Implementations
Sourceimpl Debug for FlatLayout
impl Debug for FlatLayout
Sourceimpl LayoutStrategy for FlatLayout
Implement the LayoutStrategy trait for the FlatLayout for easy use.
impl LayoutStrategy for FlatLayout
Implement the LayoutStrategy trait for the FlatLayout for easy use.
fn new_writer( &self, ctx: &ArrayContext, dtype: &DType, ) -> VortexResult<Box<dyn LayoutWriter>>
Sourceimpl LayoutVTable for FlatLayout
impl LayoutVTable for FlatLayout
Sourcefn reader(
&self,
layout: Layout,
ctx: ArrayContext,
segment_reader: Arc<dyn AsyncSegmentReader>,
) -> VortexResult<Arc<dyn LayoutReader>>
fn reader( &self, layout: Layout, ctx: ArrayContext, segment_reader: Arc<dyn AsyncSegmentReader>, ) -> VortexResult<Arc<dyn LayoutReader>>
Sourcefn register_splits(
&self,
layout: &Layout,
field_mask: &[FieldMask],
row_offset: u64,
splits: &mut BTreeSet<u64>,
) -> VortexResult<()>
fn register_splits( &self, layout: &Layout, field_mask: &[FieldMask], row_offset: u64, splits: &mut BTreeSet<u64>, ) -> VortexResult<()>
Register the row splits for this layout, these represent natural boundaries at which
a reader can split the layout for independent processing. Read more
fn required_segments( &self, layout: &Layout, row_offset: u64, _filter_field_mask: &[FieldMask], _projection_field_mask: &[FieldMask], segments: &mut SegmentCollector, ) -> VortexResult<()>