pub struct StatsTable { /* private fields */ }Expand description
A table of statistics for a column. Each row of the stats table corresponds to a chunk of the column.
Note that it’s possible for the stats table to have no statistics.
Implementations
Sourceimpl StatsTable
impl StatsTable
Sourcepub fn try_new(
column_dtype: DType,
array: ArrayRef,
stats: Arc<[Stat]>,
) -> VortexResult<Self>
pub fn try_new( column_dtype: DType, array: ArrayRef, stats: Arc<[Stat]>, ) -> VortexResult<Self>
Create StatsTable of given column_dtype from given array. Validates that the array matches expected structure for given list of stats
Sourcepub fn unchecked_new(array: ArrayRef, stats: Arc<[Stat]>) -> Self
pub fn unchecked_new(array: ArrayRef, stats: Arc<[Stat]>) -> Self
Create StatsTable without validating return array against expected stats
Sourcepub fn dtype_for_stats_table(
column_dtype: &DType,
present_stats: &[Stat],
) -> DType
pub fn dtype_for_stats_table( column_dtype: &DType, present_stats: &[Stat], ) -> DType
Returns the DType of the statistics table given a set of statistics and column DType.
Sourcepub fn present_stats(&self) -> &[Stat]
pub fn present_stats(&self) -> &[Stat]
The statistics that are included in the table.
Sourcepub fn to_stats_set(&self, stats: &[Stat]) -> VortexResult<StatsSet>
pub fn to_stats_set(&self, stats: &[Stat]) -> VortexResult<StatsSet>
Return an aggregated stats set for the table.