pub struct StatsLayout;Trait Implementations
Sourceimpl Debug for StatsLayout
impl Debug for StatsLayout
Sourceimpl Default for StatsLayout
impl Default for StatsLayout
Sourcefn default() -> StatsLayout
fn default() -> StatsLayout
Returns the “default value” for a type. Read more
Sourceimpl LayoutVTable for StatsLayout
First child contains the data, second child contains the statistics table.
impl LayoutVTable for StatsLayout
First child contains the data, second child contains the statistics table.
Sourcefn reader(
&self,
layout: Layout,
segment_source: &Arc<dyn SegmentSource>,
ctx: &ArrayContext,
) -> VortexResult<Arc<dyn LayoutReader>>
fn reader( &self, layout: Layout, segment_source: &Arc<dyn SegmentSource>, ctx: &ArrayContext, ) -> VortexResult<Arc<dyn LayoutReader>>