pub struct StructLayout;Trait Implementations
Sourceimpl Debug for StructLayout
impl Debug for StructLayout
Sourceimpl LayoutEncoding for StructLayout
impl LayoutEncoding for StructLayout
Sourcefn reader(
&self,
layout: LayoutData,
ctx: ContextRef,
segments: Arc<dyn AsyncSegmentReader>,
) -> VortexResult<Arc<dyn LayoutReader>>
fn reader( &self, layout: LayoutData, ctx: ContextRef, segments: Arc<dyn AsyncSegmentReader>, ) -> VortexResult<Arc<dyn LayoutReader>>
Sourcefn register_splits(
&self,
layout: &LayoutData,
field_mask: &[FieldMask],
row_offset: u64,
splits: &mut BTreeSet<u64>,
) -> VortexResult<()>
fn register_splits( &self, layout: &LayoutData, field_mask: &[FieldMask], row_offset: u64, splits: &mut BTreeSet<u64>, ) -> VortexResult<()>
Register the row splits for this layout, these represent natural boundaries at which
a reader can split the layout for independent processing. Read more