pub struct ZoneMap { /* private fields */ }Expand description
A zone map containing statistics for a column. Each row of the zone map corresponds to a chunk of the column.
Note that it’s possible for the zone map to have no statistics.
Implementations
Sourceimpl ZoneMap
impl ZoneMap
Sourcepub fn try_new(
column_dtype: DType,
array: StructArray,
stats: Arc<[Stat]>,
zone_len: u64,
row_count: u64,
) -> VortexResult<Self>
pub fn try_new( column_dtype: DType, array: StructArray, stats: Arc<[Stat]>, zone_len: u64, row_count: u64, ) -> VortexResult<Self>
Create ZoneMap of given column_dtype from given array. Validates that the array matches expected
structure for given list of stats.
Sourcepub unsafe fn new_unchecked(
array: StructArray,
zone_len: u64,
row_count: u64,
) -> Self
pub unsafe fn new_unchecked( array: StructArray, zone_len: u64, row_count: u64, ) -> Self
Sourcepub fn dtype_for_stats_table(
column_dtype: &DType,
present_stats: &[Stat],
) -> DType
👎Deprecated: use stats_table_dtype from crate::layouts::zoned::schema instead
pub fn dtype_for_stats_table( column_dtype: &DType, present_stats: &[Stat], ) -> DType
use stats_table_dtype from crate::layouts::zoned::schema instead
Sourcepub fn prune(
&self,
predicate: &Expression,
session: &VortexSession,
) -> VortexResult<Mask>
pub fn prune( &self, predicate: &Expression, session: &VortexSession, ) -> VortexResult<Mask>
Apply a pruning predicate to this zone map.
predicate should be the result of converting a filter with
checked_pruning_expr. The returned mask has one value per zone, where
true means the zone cannot contain matching rows and can be skipped.
If the predicate contains row_count
placeholders, they are replaced after ArrayRef::apply with per-zone
counts derived from zone_len and row_count. Uniform zones use a
ConstantArray; a short final zone uses a run-end encoded array.