pub struct ScanBuilder<A> { /* private fields */ }Expand description
A struct for building a scan operation.
Implementations
Sourceimpl<A: 'static + Send> ScanBuilder<A>
impl<A: 'static + Send> ScanBuilder<A>
pub fn with_filter(self, filter: ExprRef) -> Self
pub fn with_some_filter(self, filter: Option<ExprRef>) -> Self
pub fn with_projection(self, projection: ExprRef) -> Self
pub fn with_row_range(self, row_range: Range<u64>) -> Self
pub fn with_some_row_range(self, row_range: Option<Range<u64>>) -> Self
pub fn with_selection(self, selection: Selection) -> Self
pub fn with_row_indices(self, row_indices: Buffer<u64>) -> Self
pub fn with_split_by(self, split_by: SplitBy) -> Self
Sourcepub fn with_concurrency(self, concurrency: usize) -> Self
pub fn with_concurrency(self, concurrency: usize) -> Self
The number of row splits to make progress on concurrently, must be greater than 0.
pub fn with_executor(self, executor: Arc<dyn TaskExecutor>) -> Self
pub fn with_metrics(self, metrics: VortexMetrics) -> Self
pub fn with_prune_file_on_open(self, stats_set: Arc<[StatsSet]>) -> Self
Sourcepub fn map<B: 'static>(
self,
map_fn: impl Fn(A) -> VortexResult<B> + 'static + Send + Sync,
) -> ScanBuilder<B>
pub fn map<B: 'static>( self, map_fn: impl Fn(A) -> VortexResult<B> + 'static + Send + Sync, ) -> ScanBuilder<B>
Map each split of the scan. The function will be run on the spawned task.
Sourcepub fn dtype(&self) -> VortexResult<DType>
pub fn dtype(&self) -> VortexResult<DType>
Returns the output DType of the scan.
Sourcepub fn build(
self,
) -> VortexResult<Vec<impl Future<Output = VortexResult<Option<A>>>>>
pub fn build( self, ) -> VortexResult<Vec<impl Future<Output = VortexResult<Option<A>>>>>
Constructs a task per row split of the scan, returned as a vector of futures.
Sourcepub fn into_stream(
self,
) -> VortexResult<impl Stream<Item = VortexResult<A>> + 'static>
pub fn into_stream( self, ) -> VortexResult<impl Stream<Item = VortexResult<A>> + 'static>
Returns a stream over the scan objects.
Sourceimpl ScanBuilder<ArrayRef>
impl ScanBuilder<ArrayRef>
pub fn new(layout_reader: Arc<dyn LayoutReader>) -> Self
Sourcepub fn map_to_record_batch(self, schema: SchemaRef) -> ScanBuilder<RecordBatch>
pub fn map_to_record_batch(self, schema: SchemaRef) -> ScanBuilder<RecordBatch>
Map the scan into a stream of Arrow RecordBatch.
Sourcepub fn into_array_stream(self) -> VortexResult<impl ArrayStream + 'static>
pub fn into_array_stream(self) -> VortexResult<impl ArrayStream + 'static>
Returns a stream over the scan with each CPU task polled on the current thread as per
the behaviour of futures::stream::Buffered.
Sourcepub fn into_array_iter(self) -> VortexResult<impl ArrayIterator + 'static>
pub fn into_array_iter(self) -> VortexResult<impl ArrayIterator + 'static>
Returns a blocking iterator over the scan.
All work will be performed on the current thread, with tasks interleaved per the configured concurrency. Any configured executor will be ignored.