pub struct SplitRange { /* private fields */ }Expand description
A row range used when registering natural scan splits.
Row range is relative to the reader that receives it. Offset is the offset that the local row range needs to be shifted by to get the global row range.
Implementations
Sourceimpl SplitRange
impl SplitRange
Sourcepub fn try_new(row_offset: u64, row_range: Range<u64>) -> VortexResult<Self>
pub fn try_new(row_offset: u64, row_range: Range<u64>) -> VortexResult<Self>
Constructs a split range, returning an error if the local row range is invalid.
Sourcepub fn root(row_range: Range<u64>) -> VortexResult<Self>
pub fn root(row_range: Range<u64>) -> VortexResult<Self>
Constructs a split range for the root layout.
Sourcepub fn row_offset(&self) -> u64
pub fn row_offset(&self) -> u64
The root-layout row offset of this reader’s local row zero.
Sourcepub fn root_row_range(&self) -> Range<u64>
pub fn root_row_range(&self) -> Range<u64>
Returns the equivalent row range in the root layout’s coordinate space.
Sourcepub fn check_bounds(&self, row_count: u64) -> VortexResult<()>
pub fn check_bounds(&self, row_count: u64) -> VortexResult<()>
Returns an error if the local row range is outside the given row count.