pub trait LayoutWriterExt: LayoutWriter {
// Provided methods
fn boxed(self) -> Box<dyn LayoutWriter>
where Self: Sized + 'static { ... }
fn push_one(
&mut self,
segment_writer: &mut dyn SegmentWriter,
chunk: ArrayRef,
) -> VortexResult<LayoutRef> { ... }
fn push_all<I: IntoIterator<Item = VortexResult<ArrayRef>>>(
&mut self,
segment_writer: &mut dyn SegmentWriter,
iter: I,
) -> VortexResult<LayoutRef> { ... }
}Provided Methods
Sourcefn boxed(self) -> Box<dyn LayoutWriter>where
Self: Sized + 'static,
fn boxed(self) -> Box<dyn LayoutWriter>where
Self: Sized + 'static,
Box the layout writer.
Sourcefn push_one(
&mut self,
segment_writer: &mut dyn SegmentWriter,
chunk: ArrayRef,
) -> VortexResult<LayoutRef>
fn push_one( &mut self, segment_writer: &mut dyn SegmentWriter, chunk: ArrayRef, ) -> VortexResult<LayoutRef>
Push a single chunk into the layout writer and return the finished LayoutRef.
Sourcefn push_all<I: IntoIterator<Item = VortexResult<ArrayRef>>>(
&mut self,
segment_writer: &mut dyn SegmentWriter,
iter: I,
) -> VortexResult<LayoutRef>
fn push_all<I: IntoIterator<Item = VortexResult<ArrayRef>>>( &mut self, segment_writer: &mut dyn SegmentWriter, iter: I, ) -> VortexResult<LayoutRef>
Push all chunks of the iterator into the layout writer and return the finished
LayoutRef.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.