pub trait StatsEvaluator {
// Required method
fn evaluate_stats<'life0, 'async_trait>(
&'life0 self,
field_paths: Arc<[FieldPath]>,
stats: Arc<[Stat]>,
) -> Pin<Box<dyn Future<Output = VortexResult<Vec<StatsSet>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
A trait for evaluating field statistics against a LayoutReader.
Implementations should avoid fetching data segments (metadata segments are ok) and instead rely on the statistics that were computed at write time.