Re-exports
pub use vtable::*;
Modules
- layouts
- A collection of built-in layouts for Vortex
- segments
- strategies
- This is a collection of built-in layout strategies designed to be used in conjunction with one another to develop an overall strategy.
- vtable
Structs
- Layout
Layoutis the lazy equivalent tovortex_array::Array, providing a hierarchical structure.- Layout
Context - Layout
Id - Owned
Layout - A layout that is fully deserialized and heap-allocated.
Traits
- Expr
Evaluator - A trait for evaluating expressions against a
LayoutReader. - Layout
Reader - A
LayoutReaderis an instance of aLayoutthat can cache state across multiple operations. - Layout
Reader Ext - Stats
Evaluator - A trait for evaluating field statistics against a
LayoutReader.