Crate vortex_layout

Modules

layouts
A collection of built-in layouts for Vortex
segments
strategies
This is a collection of built-in layout strategies designed to be used in conjunction with one another to develop an overall strategy.

Structs

LayoutContext
LayoutData
LayoutData is the lazy equivalent to vortex_array::ArrayData, providing a hierarchical structure.
LayoutId
OwnedLayoutData
A layout that is fully deserialized and heap-allocated.

Traits

ExprEvaluator
A trait for evaluating expressions against a LayoutReader.
LayoutEncoding
LayoutReader
A LayoutReader is an instance of a LayoutData that can cache state across multiple operations.
LayoutReaderExt
StatsEvaluator
A trait for evaluating field statistics against a LayoutReader.

Type Aliases

LayoutContextRef
LayoutEncodingRef