pub struct StatsAccumulator { /* private fields */ }Expand description
Accumulates statistics for a column.
TODO(ngates): we should make it such that the stats table stores a mirror of the DType
underneath each stats column. For example, min: i32 for an i32 array.
Or min: {a: i32, b: i32} for a struct array of type {a: i32, b: i32}.
See: https://github.com/spiraldb/vortex/issues/1835
Implementations
Sourceimpl StatsAccumulator
impl StatsAccumulator
pub fn new(dtype: DType, stats: Vec<Stat>) -> Self
pub fn push_chunk(&mut self, array: &ArrayData) -> VortexResult<()>
Sourcepub fn as_stats_table(&mut self) -> VortexResult<Option<StatsTable>>
pub fn as_stats_table(&mut self) -> VortexResult<Option<StatsTable>>
Finishes the accumulator into a StatsTable.
Returns None if none of the requested statistics can be computed, for example they are
not applicable to the column’s data type.