pub struct StatsTable { /* private fields */ }Expand description
A table of statistics for a column. Each row of the stats table corresponds to a chunk of the column.
Note that it’s possible for the stats table to have no statistics.
Implementations
Sourceimpl StatsTable
impl StatsTable
pub fn try_new( column_dtype: DType, array: ArrayData, stats: Arc<[Stat]>, ) -> VortexResult<Self>
Sourcepub fn dtype_for_stats_table(
column_dtype: &DType,
present_stats: &[Stat],
) -> DType
pub fn dtype_for_stats_table( column_dtype: &DType, present_stats: &[Stat], ) -> DType
Returns the DType of the statistics table given a set of statistics and column DType.
Sourcepub fn column_dtype(&self) -> &DType
pub fn column_dtype(&self) -> &DType
The DType of the column for which these stats are computed.
Sourcepub fn present_stats(&self) -> &[Stat]
pub fn present_stats(&self) -> &[Stat]
The statistics that are included in the table.
Sourcepub fn to_stats_set(&self, stats: &[Stat]) -> VortexResult<StatsSet>
pub fn to_stats_set(&self, stats: &[Stat]) -> VortexResult<StatsSet>
Return an aggregated stats set for the table.