pub struct ChunkedLayout;Trait Implementations
Sourceimpl Debug for ChunkedLayout
impl Debug for ChunkedLayout
Sourceimpl Default for ChunkedLayout
impl Default for ChunkedLayout
Sourcefn default() -> ChunkedLayout
fn default() -> ChunkedLayout
Returns the “default value” for a type. Read more
Sourceimpl LayoutEncoding for ChunkedLayout
In-memory representation of Chunked layout.
impl LayoutEncoding for ChunkedLayout
In-memory representation of Chunked layout.
First child in the list is the metadata table Subsequent children are consecutive chunks of this layout
Sourcefn reader(
&self,
layout: LayoutData,
ctx: ContextRef,
segments: Arc<dyn AsyncSegmentReader>,
) -> VortexResult<Arc<dyn LayoutReader>>
fn reader( &self, layout: LayoutData, ctx: ContextRef, segments: Arc<dyn AsyncSegmentReader>, ) -> VortexResult<Arc<dyn LayoutReader>>
Sourcefn register_splits(
&self,
layout: &LayoutData,
field_mask: &[FieldMask],
row_offset: u64,
splits: &mut BTreeSet<u64>,
) -> VortexResult<()>
fn register_splits( &self, layout: &LayoutData, field_mask: &[FieldMask], row_offset: u64, splits: &mut BTreeSet<u64>, ) -> VortexResult<()>
Register the row splits for this layout, these represent natural boundaries at which
a reader can split the layout for independent processing. Read more