pub struct ChunkedLayoutWriter { /* private fields */ }Expand description
A basic implementation of a chunked layout writer that writes each batch into its own chunk.
TODO(ngates): introduce more sophisticated layout writers with different chunking strategies.
Implementations
Sourceimpl ChunkedLayoutWriter
impl ChunkedLayoutWriter
pub fn new( ctx: ArrayContext, dtype: DType, options: ChunkedLayoutStrategy, ) -> Self