pub struct DictStrategy {
pub options: DictLayoutOptions,
pub codes: ArcRef<dyn LayoutStrategy>,
pub values: ArcRef<dyn LayoutStrategy>,
pub fallback: ArcRef<dyn LayoutStrategy>,
}Expand description
A layout strategy that encodes chunk into values and codes, if found appropriate by the btrblocks compressor. Current implementation only checks the first chunk to decide whether to apply dict layout and encodes chunks into dictionaries. When the dict constraints are hit, a new dictionary is created.
Fields
options: DictLayoutOptionscodes: ArcRef<dyn LayoutStrategy>values: ArcRef<dyn LayoutStrategy>fallback: ArcRef<dyn LayoutStrategy>Trait Implementations
Sourceimpl Clone for DictStrategy
impl Clone for DictStrategy
Sourcefn clone(&self) -> DictStrategy
fn clone(&self) -> DictStrategy
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl LayoutStrategy for DictStrategy
impl LayoutStrategy for DictStrategy
fn new_writer( &self, ctx: &ArrayContext, dtype: &DType, ) -> VortexResult<Box<dyn LayoutWriter>>