Struct DictStrategy

pub struct DictStrategy {
    pub options: DictLayoutOptions,
    pub codes: ArcRef<dyn LayoutStrategy>,
    pub values: ArcRef<dyn LayoutStrategy>,
    pub fallback: ArcRef<dyn LayoutStrategy>,
}
A layout strategy that encodes chunk into values and codes, if found appropriate by the btrblocks compressor. Current implementation only checks the first chunk to decide whether to apply dict layout and encodes chunks into dictionaries. When the dict constraints are hit, a new dictionary is created.

Fields

options: DictLayoutOptionscodes: ArcRef<dyn LayoutStrategy>values: ArcRef<dyn LayoutStrategy>fallback: ArcRef<dyn LayoutStrategy>