pub struct FlatLayout;Trait Implementations
Sourceimpl Debug for FlatLayout
impl Debug for FlatLayout
Sourceimpl LayoutEncoding for FlatLayout
impl LayoutEncoding for FlatLayout
Sourcefn reader(
&self,
layout: LayoutData,
ctx: ContextRef,
segments: Arc<dyn AsyncSegmentReader>,
) -> VortexResult<Arc<dyn LayoutReader>>
fn reader( &self, layout: LayoutData, ctx: ContextRef, segments: Arc<dyn AsyncSegmentReader>, ) -> VortexResult<Arc<dyn LayoutReader>>
Sourcefn register_splits(
&self,
layout: &LayoutData,
field_mask: &[FieldMask],
row_offset: u64,
splits: &mut BTreeSet<u64>,
) -> VortexResult<()>
fn register_splits( &self, layout: &LayoutData, field_mask: &[FieldMask], row_offset: u64, splits: &mut BTreeSet<u64>, ) -> VortexResult<()>
Register the row splits for this layout, these represent natural boundaries at which
a reader can split the layout for independent processing. Read more
Sourceimpl LayoutStrategy for FlatLayout
Implement the LayoutStrategy trait for the FlatLayout for easy use.
impl LayoutStrategy for FlatLayout
Implement the LayoutStrategy trait for the FlatLayout for easy use.
fn new_writer(&self, dtype: &DType) -> VortexResult<Box<dyn LayoutWriter>>