Module table

Module table 

A configurable writer strategy for tabular data.

Allows the caller to override specific leaf fields with custom layout strategies.

Structs

TableStrategy
A configurable strategy for writing tables with nested field columns, allowing overrides for specific leaf columns.