A configurable writer strategy for tabular data.
Allows the caller to override specific leaf fields with custom layout strategies.
Structs
- Table
Strategy - A configurable strategy for writing tables with nested field columns, allowing overrides for specific leaf columns.