pub struct TableStrategy { /* private fields */ }Expand description
A configurable strategy for writing nested tabular data, dispatching each (sub)stream to the structural writer for its dtype.
Dispatch rules, applied to the dtype of the stream handed to write_stream:
- struct →
StructStrategy, with each field written by its override (if any) or by a descended copy of this dispatcher. - anything else → the leaf strategy.
Implementations
Sourceimpl TableStrategy
impl TableStrategy
Sourcepub fn new(
validity: Arc<dyn LayoutStrategy>,
fallback: Arc<dyn LayoutStrategy>,
) -> Self
pub fn new( validity: Arc<dyn LayoutStrategy>, fallback: Arc<dyn LayoutStrategy>, ) -> Self
Create a new dispatcher with the given validity strategy and fallback leaf strategy and
no overrides.
Additional per-field overrides can be configured with
with_field_writer.
Example
ⓘ
// Build a write strategy that does not compress validity or any leaf fields.
let flat = Arc::new(FlatLayoutStrategy::default());
let strategy = TableStrategy::new(Arc::<FlatLayoutStrategy>::clone(&flat), Arc::<FlatLayoutStrategy>::clone(&flat));Sourcepub fn with_field_writer(
self,
field_path: impl Into<FieldPath>,
writer: Arc<dyn LayoutStrategy>,
) -> Self
pub fn with_field_writer( self, field_path: impl Into<FieldPath>, writer: Arc<dyn LayoutStrategy>, ) -> Self
Add a custom write strategy for the given leaf field.
Example
ⓘ
// A strategy for compressing data using the balanced BtrBlocks compressor.
let compress =
CompressingStrategy::new(FlatLayoutStrategy::default(), BtrBlocksCompressor::default());
// Our combined strategy uses no compression for validity buffers, BtrBlocks compression
// for most columns, and stores a nested binary column uncompressed (flat) because it
// is pre-compressed or never filtered on.
let strategy = TableStrategy::new(
Arc::new(FlatLayoutStrategy::default()),
Arc::new(compress),
)
.with_field_writer(
field_path!(request.body.bytes),
Arc::new(FlatLayoutStrategy::default()),
);Sourcepub fn with_field_writers(
self,
writers: impl IntoIterator<Item = (FieldPath, Arc<dyn LayoutStrategy>)>,
) -> Self
pub fn with_field_writers( self, writers: impl IntoIterator<Item = (FieldPath, Arc<dyn LayoutStrategy>)>, ) -> Self
Set writers for several fields at once.
See also: with_field_writer.
Sourcepub fn with_default_strategy(self, default: Arc<dyn LayoutStrategy>) -> Self
pub fn with_default_strategy(self, default: Arc<dyn LayoutStrategy>) -> Self
Override the default strategy for leaf columns that don’t have overrides.
Sourcepub fn with_validity_strategy(self, validity: Arc<dyn LayoutStrategy>) -> Self
pub fn with_validity_strategy(self, validity: Arc<dyn LayoutStrategy>) -> Self
Override the strategy for compressing struct validity at all levels of the schema tree.