pub fn plan_row_idx_expression(
expression: BoundExpression,
child: PlanRef,
) -> VortexResult<PlanRef>Expand description
Plans an expression over a data source and its global row-index domain.
Expressions that only use data bypass the row-index source, expressions that only use
#row_idx bypass child, and mixed expressions combine independently planned branches with a
PackPlan. The file row offset is supplied by the execution row domain.