pub struct ScanBuilder<D: ScanDriver> { /* private fields */ }Expand description
A struct for building a scan operation.
Implementations
Sourceimpl<D: ScanDriver> ScanBuilder<D>
impl<D: ScanDriver> ScanBuilder<D>
pub fn new(driver: D, layout: Layout, ctx: ArrayContext) -> Self
pub fn with_filter(self, filter: ExprRef) -> Self
pub fn with_some_filter(self, filter: Option<ExprRef>) -> Self
pub fn with_projection(self, projection: ExprRef) -> Self
pub fn with_row_indices(self, row_indices: Buffer<u64>) -> Self
pub fn with_some_row_indices(self, row_indices: Option<Buffer<u64>>) -> Self
pub fn with_split_by(self, split_by: SplitBy) -> Self
Sourcepub fn with_canonicalize(self, canonicalize: bool) -> Self
pub fn with_canonicalize(self, canonicalize: bool) -> Self
Set whether the scan should canonicalize the output.
Sourcepub fn with_concurrency(self, concurrency: usize) -> Self
pub fn with_concurrency(self, concurrency: usize) -> Self
The number of row splits to make progress on concurrently, must be greater than 0.
Sourcepub fn with_prefetch_conjuncts(self, prefetch: bool) -> Self
pub fn with_prefetch_conjuncts(self, prefetch: bool) -> Self
The number of row splits to make progress on concurrently, must be greater than 0.
pub fn with_task_executor(self, task_executor: TaskExecutor) -> Self
pub fn with_metrics(self, metrics: VortexMetrics) -> Self
pub fn build(self) -> VortexResult<Scan<D>>
Sourcepub fn into_array_stream(self) -> VortexResult<impl ArrayStream + 'static>
pub fn into_array_stream(self) -> VortexResult<impl ArrayStream + 'static>
Perform the scan operation and return a stream of arrays.
pub async fn read_all(self) -> VortexResult<ArrayRef>