This is a collection of built-in layout strategies designed to be used in conjunction with one another to develop an overall strategy.
Each LayoutWriter is passed horizontal chunks of a Vortex array one-by-one, and is
eventually asked to return a Layout. The writers can buffer, re-chunk, flush, or
otherwise manipulate the chunks of data enabling experimentation with different strategies
all while remaining independent of the read code.
Structs
- Vortex
Layout Strategy - The default Vortex file layout strategy.
Traits
- Layout
Strategy - A trait for creating new layout writers given a DType.
- Layout
Writer - A strategy for writing chunks of an array into a layout. FIXME(ngates): move this into writer.rs
- Layout
Writer Ext