pub struct Layout<V: VTable> { /* private fields */ }Expand description
A typed layout node.
Implementations
Sourceimpl Layout<Chunked>
impl Layout<Chunked>
Sourcepub fn new(
row_count: u64,
dtype: DType,
children: Arc<dyn LayoutChildren>,
) -> Self
pub fn new( row_count: u64, dtype: DType, children: Arc<dyn LayoutChildren>, ) -> Self
Construct a chunked layout.
Sourcepub fn with_children(&self, children: Vec<LayoutRef>) -> Self
pub fn with_children(&self, children: Vec<LayoutRef>) -> Self
Rebuild this layout with owned children.
Sourceimpl Layout<Dict>
impl Layout<Dict>
Sourcepub fn has_all_values_referenced(&self) -> bool
pub fn has_all_values_referenced(&self) -> bool
Returns whether every dictionary value is known to be referenced.
Sourceimpl Layout<Flat>
impl Layout<Flat>
Sourcepub fn new(
row_count: u64,
dtype: DType,
segment_id: SegmentId,
ctx: ReadContext,
) -> Self
pub fn new( row_count: u64, dtype: DType, segment_id: SegmentId, ctx: ReadContext, ) -> Self
Construct a flat layout without an inline array encoding tree.
Sourcepub fn new_with_metadata(
row_count: u64,
dtype: DType,
segment_id: SegmentId,
ctx: ReadContext,
array_tree: Option<ByteBuffer>,
) -> Self
pub fn new_with_metadata( row_count: u64, dtype: DType, segment_id: SegmentId, ctx: ReadContext, array_tree: Option<ByteBuffer>, ) -> Self
Construct a flat layout with optional inline array metadata.
Sourcepub fn segment_id(&self) -> SegmentId
pub fn segment_id(&self) -> SegmentId
Returns the serialized array segment ID.
Sourcepub fn array_ctx(&self) -> &ReadContext
pub fn array_ctx(&self) -> &ReadContext
Returns the array read context.
Sourcepub fn array_tree(&self) -> Option<&ByteBuffer>
pub fn array_tree(&self) -> Option<&ByteBuffer>
Returns the optional inline array encoding tree.
Sourceimpl Layout<List>
impl Layout<List>
Sourcepub fn new(
dtype: DType,
elements: LayoutRef,
offsets: LayoutRef,
validity: Option<LayoutRef>,
) -> Self
pub fn new( dtype: DType, elements: LayoutRef, offsets: LayoutRef, validity: Option<LayoutRef>, ) -> Self
Construct a list layout from its children.
Sourcepub fn elements(&self) -> VortexResult<LayoutRef>
pub fn elements(&self) -> VortexResult<LayoutRef>
Returns the elements child.
Sourcepub fn offsets(&self) -> VortexResult<LayoutRef>
pub fn offsets(&self) -> VortexResult<LayoutRef>
Returns the offsets child.
Sourcepub fn validity(&self) -> VortexResult<Option<LayoutRef>>
pub fn validity(&self) -> VortexResult<Option<LayoutRef>>
Returns the optional validity child.
Sourcepub fn offsets_ptype(&self) -> PType
pub fn offsets_ptype(&self) -> PType
Returns the integer ptype used by offsets.
Sourcepub fn elements_dtype(&self) -> &DType
pub fn elements_dtype(&self) -> &DType
Returns the list element dtype.
Sourceimpl Layout<Struct>
impl Layout<Struct>
Sourcepub fn new(row_count: u64, dtype: DType, children: Vec<LayoutRef>) -> Self
pub fn new(row_count: u64, dtype: DType, children: Vec<LayoutRef>) -> Self
Construct a struct layout from owned children.
Sourcepub fn struct_fields(&self) -> &StructFields
pub fn struct_fields(&self) -> &StructFields
Returns the struct fields.
Sourcepub fn matching_fields<F>(
&self,
field_mask: &[FieldMask],
per_child: F,
) -> VortexResult<()>
pub fn matching_fields<F>( &self, field_mask: &[FieldMask], per_child: F, ) -> VortexResult<()>
Invokes per_child for fields selected by field_mask.
Sourceimpl Layout<LegacyStats>
impl Layout<LegacyStats>
Sourceimpl Layout<Zoned>
impl Layout<Zoned>
Sourcepub fn try_new(
data: LayoutRef,
zones: LayoutRef,
zone_len: NonZeroUsize,
aggregate_fns: Arc<[AggregateFnRef]>,
) -> VortexResult<Self>
pub fn try_new( data: LayoutRef, zones: LayoutRef, zone_len: NonZeroUsize, aggregate_fns: Arc<[AggregateFnRef]>, ) -> VortexResult<Self>
Create a zoned layout from a data child, a zone-map child, a zone length, and the aggregate functions stored in the zone map.
pub fn zone_len(&self) -> usize
Sourcepub fn present_aggregates(&self) -> Arc<[String]> ⓘ
pub fn present_aggregates(&self) -> Arc<[String]> ⓘ
Returns display names for the zone-map aggregates stored by this layout.
pub fn nzones(&self) -> usize
Sourceimpl<V: VTable> Layout<V>
impl<V: VTable> Layout<V>
Sourcepub fn from_parts(parts: LayoutParts<V>) -> Self
pub fn from_parts(parts: LayoutParts<V>) -> Self
Construct a layout from explicit parts.
Sourcepub fn data(&self) -> &V::LayoutData
pub fn data(&self) -> &V::LayoutData
Returns layout-specific data.
Sourcepub fn segment_ids(&self) -> &[SegmentId]
pub fn segment_ids(&self) -> &[SegmentId]
Returns directly referenced segment IDs.
Sourcepub fn children(&self) -> &Arc<dyn LayoutChildren> ⓘ
pub fn children(&self) -> &Arc<dyn LayoutChildren> ⓘ
Returns the child adapter.
Sourcepub fn nslots(&self) -> usize
pub fn nslots(&self) -> usize
Returns the number of logical child slots, including any that are absent.
Sourcepub fn slot_to_child(&self, slot: usize) -> Option<usize>
pub fn slot_to_child(&self, slot: usize) -> Option<usize>
Maps a logical slot to the index of its serialized child, or None if absent.
Sourcepub fn slot(&self, slot: usize) -> VortexResult<Option<LayoutRef>>
pub fn slot(&self, slot: usize) -> VortexResult<Option<LayoutRef>>
Materialize the child in logical slot, or None if the slot is absent.
Sourcepub fn slot_type(&self, slot: usize) -> Option<LayoutChildType>
pub fn slot_type(&self, slot: usize) -> Option<LayoutChildType>
Returns the relationship of the child in logical slot to this layout, or None if the
slot is absent.
Sourcepub fn child_row_count(&self, idx: usize) -> u64
pub fn child_row_count(&self, idx: usize) -> u64
Returns a child’s serialized row count without materializing it.
Sourcepub fn into_layout(self) -> LayoutRef
pub fn into_layout(self) -> LayoutRef
Erase this typed layout into a shared layout reference.
Sourcepub fn new_reader(
&self,
name: Arc<str>,
segment_source: Arc<dyn SegmentSource>,
session: &VortexSession,
ctx: &LayoutReaderContext,
) -> VortexResult<LayoutReaderRef>
pub fn new_reader( &self, name: Arc<str>, segment_source: Arc<dyn SegmentSource>, session: &VortexSession, ctx: &LayoutReaderContext, ) -> VortexResult<LayoutReaderRef>
Construct a reader for this layout.