LayoutChildren

Trait LayoutChildren 

pub trait LayoutChildren:
    'static
    + Send
    + Sync {
    // Required methods
    fn to_arc(&self) -> Arc<dyn LayoutChildren> ;
    fn child(&self, idx: usize, dtype: &DType) -> VortexResult<LayoutRef>;
    fn child_row_count(&self, idx: usize) -> u64;
    fn nchildren(&self) -> usize;
}
Abstract way of accessing the children of a layout.

This allows us to abstract over the lazy flatbuffer-based layouts, as well as the in-memory layout trees.

Required Methods

fn to_arc(&self) -> Arc<dyn LayoutChildren>

fn child(&self, idx: usize, dtype: &DType) -> VortexResult<LayoutRef>

fn child_row_count(&self, idx: usize) -> u64

fn nchildren(&self) -> usize