pub trait LayoutReader:
'static
+ Send
+ Sync
+ Deref<Target = dyn Layout> {
// Required methods
fn name(&self) -> &Arc<str>;
fn pruning_evaluation(
&self,
row_range: &Range<u64>,
expr: &ExprRef,
) -> VortexResult<Box<dyn PruningEvaluation>>;
fn filter_evaluation(
&self,
row_range: &Range<u64>,
expr: &ExprRef,
) -> VortexResult<Box<dyn MaskEvaluation>>;
fn projection_evaluation(
&self,
row_range: &Range<u64>,
expr: &ExprRef,
) -> VortexResult<Box<dyn ArrayEvaluation>>;
}Expand description
A LayoutReader is used to read a Layout in a way that can cache state across multiple
evaluation operations.
It dereferences into the underlying layout being read.
Required Methods
Sourcefn pruning_evaluation(
&self,
row_range: &Range<u64>,
expr: &ExprRef,
) -> VortexResult<Box<dyn PruningEvaluation>>
fn pruning_evaluation( &self, row_range: &Range<u64>, expr: &ExprRef, ) -> VortexResult<Box<dyn PruningEvaluation>>
Performs an approximate evaluation of the expression against the layout reader.
Sourcefn filter_evaluation(
&self,
row_range: &Range<u64>,
expr: &ExprRef,
) -> VortexResult<Box<dyn MaskEvaluation>>
fn filter_evaluation( &self, row_range: &Range<u64>, expr: &ExprRef, ) -> VortexResult<Box<dyn MaskEvaluation>>
Performs an exact evaluation of the expression against the layout reader.
Sourcefn projection_evaluation(
&self,
row_range: &Range<u64>,
expr: &ExprRef,
) -> VortexResult<Box<dyn ArrayEvaluation>>
fn projection_evaluation( &self, row_range: &Range<u64>, expr: &ExprRef, ) -> VortexResult<Box<dyn ArrayEvaluation>>
Evaluates the expression against the layout.