Trait LayoutReader

pub trait LayoutReader: 'static + ExprEvaluator {
    // Required methods
    fn layout(&self) -> &Layout;
    fn children(&self) -> VortexResult<Vec<Arc<dyn LayoutReader>>>;

    // Provided methods
    fn row_count(&self) -> u64 { ... }
    fn dtype(&self) -> &DType { ... }
}
A LayoutReader is an instance of a Layout that can cache state across multiple operations.

Since different row ranges of the reader may be evaluated by different threads, it is required to be both Send and Sync.

Required Methods

fn layout(&self) -> &Layout

Returns the Layout of this reader.

fn children(&self) -> VortexResult<Vec<Arc<dyn LayoutReader>>>

Provided Methods

fn row_count(&self) -> u64

Returns the row count of the layout.

fn dtype(&self) -> &DType

Returns the DType of the layout.

Implementors