vortex_layout

Trait LayoutReader

pub trait LayoutReader:
    Send
    + Sync
    + ExprEvaluator
    + StatsEvaluator {
    // Required method
    fn layout(&self) -> &LayoutData;
}
A LayoutReader is an instance of a LayoutData that can cache state across multiple operations.

Since different row ranges of the reader may be evaluated by different threads, it is required to be both Send and Sync.

Required Methods

fn layout(&self) -> &LayoutData

Returns the LayoutData of this reader.

Implementations on Foreign Types

Source

impl LayoutReader for Arc<dyn LayoutReader + 'static>

Implementors